package cn.com.qmth.examcloud.commons.util;

import java.io.InputStream;

import org.apache.commons.io.IOUtils;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClientBuilder;
import org.apache.http.util.EntityUtils;

import cn.com.qmth.examcloud.commons.logging.ExamCloudLog;
import cn.com.qmth.examcloud.commons.logging.ExamCloudLogFactory;

/**
 * httpclient
 *
 * @author WANGWEI
 * @date 2019年9月17日
 * @Copyright (c) 2018-? http://qmth.com.cn All Rights Reserved.
 */
public class HttpClientUtil {

	private static final ExamCloudLog LOGGER = ExamCloudLogFactory.getLog(HttpClientUtil.class);

	/**
	 * 关闭流
	 *
	 * @author WANGWEI
	 * @param resp
	 */
	public static void close(CloseableHttpResponse resp) {
		if (null != resp) {
			try {
				EntityUtils.consumeQuietly(resp.getEntity());
				resp.close();
			} catch (Exception e) {
				LOGGER.error("fail to close http response stream.", e);
			}
		}
	}

	/**
	 * GET 请求
	 *
	 * @author WANGWEI
	 * @param url
	 * @return
	 */
	public static byte[] get(String url) {
		return get(url, 1048576L);
	}

	/**
	 * GET 请求
	 *
	 * @author WANGWEI
	 * @param url
	 * @param maxByteSize
	 * @return
	 */
	public static byte[] get(String url, long maxByteSize) {

		CloseableHttpClient httpclient = HttpClientBuilder.create().build();

		HttpGet get = new HttpGet(url);
		get.setConfig(RequestConfig.custom().setConnectTimeout(10000).build());

		CloseableHttpResponse response = null;
		try {
			response = httpclient.execute(get);
			InputStream in = response.getEntity().getContent();

			byte[] byteArray = IOUtil.toLimitedByteArray(in, 1048576);
			return byteArray;
		} catch (Exception e) {
			throw new RuntimeException(e);
		} finally {
			close(response);
			IOUtils.closeQuietly(httpclient);
		}

	}

}